@@ -134,7 +134,6 @@ class IMMClient(object):
         self._wc = None  # The webclient shall be initiated on demand
         self._energymanager = None
         self.datacache = {}
-        self.webkeepalive = None
         self._keepalivesession = None
         self.fwc = None
         self.fwo = None
@@ -858,6 +857,7 @@ class XCCClient(IMMClient):
 
     def __init__(self, ipmicmd):
         super(XCCClient, self).__init__(ipmicmd)
+        self.ipmicmd.ipmi_session.register_keepalive(self.keepalive, None)
         self.adp_referer = None
 
     def reseat(self):
@@ -1344,6 +1344,10 @@ class XCCClient(IMMClient):
                 write_policy = vol.write_policy
             else:
                 write_policy = props["cpwb"]
+            if vol.default_init is not None:
+                default_init = vol.default_init
+            else:
+                default_init = props["initstate"]
             strsize = 'remainder' if vol.size is None else str(vol.size)
             if strsize in ('all', '100%'):
                 volsize = params['capacity']
@@ -1364,7 +1368,7 @@ class XCCClient(IMMClient):
                     'Requested sizes exceed available capacity')
             vols.append('{0};{1};{2};{3};{4};{5};{6};{7};{8};|'.format(
                 name, volsize, stripsize, write_policy, read_policy,
-                props['cpio'], props['ap'], props['dcp'], props['initstate']))
+                props['cpio'], props['ap'], props['dcp'], default_init))
         url = '/api/function'
         cid = params['controller'].split(',')
         cnum = cid[0]
@@ -1473,9 +1477,11 @@ class XCCClient(IMMClient):
                             spares.append(diskinfo)
                         else:
                             disks.append(diskinfo)
-                    totalsize = pool['totalCapacityStr'].replace('GB', '')
+                    totalsize = pool['totalCapacityStr'].replace(
+                        'GB', '').replace('GiB', '')
                     totalsize = int(float(totalsize) * 1024)
-                    freesize = pool['freeCapacityStr'].replace('GB', '')
+                    freesize = pool['freeCapacityStr'].replace(
+                        'GB', '').replace('GiB', '')
                     freesize = int(float(freesize) * 1024)
                     pools.append(storage.Array(
                         disks=disks, raid=pool['rdlvlstr'], volumes=volumes,
@@ -1529,14 +1535,15 @@ class XCCClient(IMMClient):
                 raise pygexc.InvalidParameterValue(
                     'Given location was unreachable by the XCC')
             raise Exception('Unhandled return: ' + repr(rt))
-        if not self.webkeepalive:
+        if not self._keepalivesession:
             self._keepalivesession = self._wc
-            self.webkeepalive = self.ipmicmd.ipmi_session.register_keepalive(
-                self.keepalive, None)
         self._wc = None
 
     def keepalive(self):
-        self._refresh_token_wc(self._keepalivesession)
+        if self.fwo and util._monotonic_time() - self.fwovintage > 15:
+            self.fwo = None
+        if self._keepalivesession:
+            self._refresh_token_wc(self._keepalivesession)
 
     def fetch_psu_firmware(self):
         psudata = self.get_cached_data('lenovo_cached_psu')
@@ -1650,9 +1657,7 @@ class XCCClient(IMMClient):
                 yield firm
 
     def detach_remote_media(self):
-        if self.webkeepalive:
-            self.ipmicmd.ipmi_session.unregister_keepalive(self.webkeepalive)
-            self._keepalivesession = None
+        self._keepalivesession = None
         rt = self.wc.grab_json_response('/api/providers/rp_vm_remote_getdisk')
         if 'items' in rt:
             slots = []
